@@ -1,12 +1,24 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: account_page.php,v 1.51 2005/07/17 21:56:21 thraxisp Exp $
+	# $Id: account_page.php,v 1.52.2.1 2007-10-13 22:32:01 giallu Exp $
 	# --------------------------------------------------------
 
 	# CALLERS
@@ -81,6 +93,7 @@
 <?php } ?>
 <div align="center">
 <form method="post" action="account_update.php">
+<?php  echo form_security_field( 'account_update' )?>
 <table class="width75" cellspacing="1">
 
 	<!-- Headings -->
@@ -187,7 +200,7 @@
 			<?php echo lang_get( 'realname' ) ?>
 		</td>
 		<td>
-			<input type="text" size="32" maxlength="64" name="realname" value="<?php echo $u_realname ?>" />
+			<input type="text" size="32" maxlength="64" name="realname" value="<?php echo string_attribute( $u_realname ) ?>" />
 		</td>
 	</tr>
 
