@@ -85,7 +85,8 @@
 		}
 
 		if ( isset( $_SERVER['HTTP_X_FORWARDED_HOST'] ) ) { // Support ProxyPass
-			$t_host = $_SERVER['HTTP_X_FORWARDED_HOST'];
+			$t_hosts = split( ',', $_SERVER['HTTP_X_FORWARDED_HOST'] );
+			$t_host = $t_hosts[0];
 		} else if ( isset( $_SERVER['HTTP_HOST'] ) ) {
 			$t_host = $_SERVER['HTTP_HOST'];
 		} else if ( isset( $_SERVER['SERVER_NAME'] ) ) {
@@ -149,6 +150,9 @@
 	#   'memcached' -> Memcached storage sessions
 	$g_session_handler = 'php';
 
+	# Session save path.  If false, uses default value as set by session handler.
+	$g_session_save_path = false;
+
 	#############################
 	# Configuration Settings
 	#############################
@@ -1938,4 +1942,4 @@
 	
 	# The twitter account password.
 	$g_twitter_password = '';
-?>
+
