@@ -1,12 +1,24 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: user_api.php,v 1.106.12.1 2007/03/06 07:00:33 vboctor Exp $
+	# $Id: user_api.php,v 1.113.2.3 2007-10-14 22:35:35 giallu Exp $
 	# --------------------------------------------------------
 
 	$t_core_dir = dirname( __FILE__ ).DIRECTORY_SEPARATOR;
@@ -36,23 +48,25 @@
 
 		$c_user_id = db_prepare_int( $p_user_id );
 
-		$t_user_table = config_get( 'mantis_user_table' );
-
 		if ( isset ( $g_cache_user[$c_user_id] ) ) {
 			return $g_cache_user[$c_user_id];
 		}
 
+		$t_user_table = config_get( 'mantis_user_table' );
+
 		$query = "SELECT *
 				  FROM $t_user_table
 				  WHERE id='$c_user_id'";
 		$result = db_query( $query );
 
 		if ( 0 == db_num_rows( $result ) ) {
+			$g_cache_user[$c_user_id] = false;
+
 			if ( $p_trigger_errors ) {
 				trigger_error( ERROR_USER_NOT_FOUND, ERROR );
-			} else {
-				return false;
 			}
+			
+			return false;
 		}
 
 		$row = db_fetch_array( $result );
@@ -163,7 +177,7 @@
 				# set flags for non-unique realnames
 				if ( config_get( 'differentiate_duplicates' ) ) {
 					user_set_field( $t_user_id, 'duplicate_realname', ON );
-					for ( $i=0 ; $i < $count ; $i++ ) {
+					for ( $i=0 ; $i < $t_count ; $i++ ) {
 						$t_id = db_result( $result, $i );
 						user_set_field( $t_id, 'duplicate_realname', ON );
 					}
@@ -628,6 +642,42 @@
 		}
 	}
 
+
+	/**
+	* Return the user avatar image URL
+	* in this first implementation, only gravatar.com avatars are supported
+	* @return array|bool an array( URL, width, height ) or false when the given user has no avatar
+	*/
+	function user_get_avatar( $p_user_id ) {
+		$t_email = strtolower( user_get_email( $p_user_id ) );
+		if ( is_blank( $t_email ) ) {
+			$t_result = false;
+		} else {
+			$t_default_image = config_get( 'default_avatar' );
+			$t_size = 80;
+
+			$t_use_ssl = false;
+			if ( isset( $_SERVER['HTTPS'] ) && ( strtolower( $_SERVER['HTTPS'] ) != 'off' ) ) {
+				$t_use_ssl = true;
+			}
+
+			if ( !$t_use_ssl ) {
+				$t_gravatar_domain = 'http://www.gravatar.com/';
+			} else {
+				$t_gravatar_domain = 'https://secure.gravatar.com/';
+			}
+
+			$t_avatar_url = $t_gravatar_domain . 'avatar.php?gravatar_id=' . md5( $t_email ) .
+				'&amp;default=' . urlencode( $t_default_image ) .
+				'&amp;size=' . $t_size .
+				'&amp;rating=G';
+			$t_result = array( $t_avatar_url, $t_size, $t_size );
+		}
+
+		return $t_result;
+	}
+
+
 	# --------------------
 	# return the user's access level
 	#  account for private project and the project user lists
@@ -1069,16 +1119,25 @@
 	# --------------------
 	# Set the user's password to the given string, encoded as appropriate
 	function user_set_password( $p_user_id, $p_password, $p_allow_protected=false ) {
-		$c_user_id = db_prepare_int( $p_user_id );
-
 		if ( !$p_allow_protected ) {
 			user_ensure_unprotected( $p_user_id );
 		}
 
-		$t_password		= auth_process_plain_password( $p_password );
-		$t_user_table	= config_get( 'mantis_user_table' );
-		$query = "UPDATE $t_user_table
-				  SET password='$t_password'
+		$t_email = user_get_field( $p_user_id, 'email' );
+		$t_username = user_get_field( $p_user_id, 'username' );
+
+		# When the password is changed, invalidate the cookie to expire sessions that
+		# may be active on all browsers.
+		$t_seed				= $t_email . $t_username;
+		$c_cookie_string	= db_prepare_string( auth_generate_unique_cookie_string( $t_seed ) );
+
+		$c_user_id		= db_prepare_int( $p_user_id );
+		$c_password		= db_prepare_string( auth_process_plain_password( $p_password ) );
+		$c_user_table	= config_get( 'mantis_user_table' );
+
+		$query = "UPDATE $c_user_table
+				  SET password='$c_password',
+				  cookie_string='$c_cookie_string'
 				  WHERE id='$c_user_id'";
 		db_query( $query );
 
