@@ -1,12 +1,24 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: utility_api.php,v 1.16 2004/10/24 19:04:38 thraxisp Exp $
+	# $Id: utility_api.php,v 1.22.2.1 2007-10-13 22:35:47 giallu Exp $
 	# --------------------------------------------------------
 
 	### Utility API ###
@@ -43,6 +55,19 @@
 		return explode( ':', $p_enum_elem );
 	}
 
+	# --------------------
+	# Get the string associated with the $p_enum value
+	function get_enum_to_array( $p_enum_string ) {
+		$t_arr = explode_enum_string( $p_enum_string );
+		$enum_count = count( $t_arr );
+		for ($i=0; $i < $enum_count;$i++) {
+			$t_s = explode_enum_arr( $t_arr[$i] );
+			$t_index = (int) $t_s[0];
+			$t_array[$t_index] = $t_s[1];
+		}
+		return $t_array;
+	}
+
 	# --------------------
 	# Get the string associated with the $p_enum value
 	function get_enum_to_string( $p_enum_string, $p_num ) {
@@ -154,21 +179,24 @@
 		}
 		return $t_result;
 	}
-	
+
 
 
 	# --------------------
 	# Sort a multi-dimensional array by one of its keys
-	function multi_sort( $p_array, $p_key, $p_direction=ASC ) {
-		if ( DESC == $p_direction ) {
+	function multi_sort( $p_array, $p_key, $p_direction=ASCENDING ) {
+		if ( DESCENDING == $p_direction ) {
 			$t_factor = -1;
 		} else {
 			# might as well allow everything else to mean ASC rather than erroring
 			$t_factor = 1;
 		}
 
-		$t_function = create_function( '$a, $b', "return $t_factor * strnatcasecmp( \$a['$p_key'], \$b['$p_key'] );" );
-		uasort( $p_array, $t_function );
+		// Security measure: see http://www.mantisbt.org/bugs/view.php?id=9704 for details
+		if ( array_key_exists( $p_key, $p_array ) ) {
+			$t_function = create_function( '$a, $b', "return $t_factor * strnatcasecmp( \$a['$p_key'], \$b['$p_key'] );" );
+			uasort( $p_array, $t_function );
+		}
 		return $p_array;
 	}
 
@@ -186,15 +214,22 @@
 	# It doesn't use gd_info() so it works with PHP < 4.3.0 as well
 	function get_gd_version()
 	{
-    $t_GDfuncList = get_extension_funcs('gd');
-    if( ! is_array( $t_GDfuncList ) ) {
-    	return 0;
-    } else {
-	    if( in_array('imagegd2',$t_GDfuncList) ) {
-	    	return 2;
-	   	} else {
-	   		return 1;
-	   	}
-	  }
+		$t_GDfuncList = get_extension_funcs('gd');
+		if( ! is_array( $t_GDfuncList ) ) {
+			return 0;
+		} else {
+			if( in_array('imagegd2',$t_GDfuncList) ) {
+				return 2;
+			} else {
+				return 1;
+			}
+		}
 	}
+	
+	# ---------------------
+	# return true or false if string matches current page name
+	function is_page_name( $p_string ) {
+	   return isset( $_SERVER['PHP_SELF'] ) && ( 0 < strpos( $_SERVER['PHP_SELF'], $p_string ) );
+	}
+	
 ?>
